Installation
============

Dependencies
------------

``pcassie`` requires the use of `astropy`, `jax`, `matplotlib`,  `numba`, `numpy <https://numpy.org/>`, and `scipy`.

Installation
------------

``pcassie`` is currently not yet available on PyPI, but it can be
installed by downloading the source code or cloning the GitHub
repository and running the standard::

       python setup.py install

command or its usual variants (``python setup.py install --user``,
``python setup.py install --prefix=/PATH/TO/INSTALL/DIRECTORY``,
etc.).

For more info, please open an Issue on the GitHub page.